.. module:: enaml.widgets.dock_item

=======================
enaml.widgets.dock_item
=======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    DockItem


.. autoclass:: DockItem
